@@ -495,6 +495,7 @@ fr_info_t *fin;
 int isdst;
 {
 	int hlen, code, leader, dlen;
+	struct net_device *ifp;
 	struct in_addr dst4;
 	struct icmp *icmp;
 	u_short sz;
@@ -572,9 +573,10 @@ int isdst;
 	icmp->icmp_type = type & 0xff;
 	icmp->icmp_code = code & 0xff;
 #ifdef	icmp_nextmtu
-	if (type == ICMP_UNREACH && (qif->qf_max_frag != 0) &&
+	ifp = fin->fin_ifp;
+	if (type == ICMP_UNREACH && (ifp->mtu != 0) &&
 	    fin->fin_icode == ICMP_UNREACH_NEEDFRAG)
-		icmp->icmp_nextmtu = htons(qif->qf_max_frag);
+		icmp->icmp_nextmtu = htons(ifp->mtu);
 #endif
 
 #ifdef	USE_INET6
