@@ -3,7 +3,7 @@
  *
  * See the IPFILTER.LICENCE file for details on licencing.
  *
- * $Id: ip_log.c,v 2.75 2004/02/11 14:18:14 darrenr Exp $
+ * $Id: ip_log.c,v 2.75.2.7 2005/06/11 07:47:44 darrenr Exp $
  */
 #include <sys/param.h>
 #if defined(KERNEL) || defined(_KERNEL)
@@ -37,11 +37,13 @@
 # include <stdlib.h>
 # include <ctype.h>
 # define _KERNEL
-#ifdef __OpenBSD__
+# define KERNEL
+# ifdef __OpenBSD__
 struct file;
-#endif
+# endif
 # include <sys/uio.h>
 # undef _KERNEL
+# undef KERNEL
 #endif
 #if __FreeBSD_version >= 220000 && defined(_KERNEL)
 # include <sys/fcntl.h>
@@ -153,6 +155,7 @@ int	ipl_buffer_sz;
 int	ipl_logmax = IPL_LOGMAX;
 int	ipl_logall = 0;
 int	ipl_log_init = 0;
+int	ipl_logsize = IPFILTER_LOGSIZE;
 int	ipl_magic[IPL_LOGSIZE] = { IPL_MAGIC, IPL_MAGIC_NAT, IPL_MAGIC_STATE,
 				   IPL_MAGIC, IPL_MAGIC, IPL_MAGIC,
 				   IPL_MAGIC, IPL_MAGIC };
@@ -316,15 +319,15 @@ u_int flags;
 	 * currently associated.
 	 */
 # if (SOLARIS || defined(__hpux)) && defined(_KERNEL)
-	ipfl.fl_unit = (u_char)ifp->qf_ppa;
+	ipfl.fl_unit = (u_int)ifp->qf_ppa;
 	COPYIFNAME(ifp, ipfl.fl_ifname);
 # else
 #  if (defined(NetBSD) && (NetBSD <= 1991011) && (NetBSD >= 199603)) || \
-      (defined(OpenBSD) && (OpenBSD >= 199603)) || \
+      (defined(OpenBSD) && (OpenBSD >= 199603)) || defined(linux) || \
       (defined(__FreeBSD__) && (__FreeBSD_version >= 501113))
 	COPYIFNAME(ifp, ipfl.fl_ifname);
 #  else
-	ipfl.fl_unit = (u_char)ifp->if_unit;
+	ipfl.fl_unit = (u_int)ifp->if_unit;
 #   if defined(_KERNEL)
 	if ((ipfl.fl_ifname[0] = ifp->if_name[0]))
 		if ((ipfl.fl_ifname[1] = ifp->if_name[1]))
@@ -407,10 +410,11 @@ void **items;
 size_t *itemsz;
 int *types, cnt;
 {
-	caddr_t buf, s;
+	caddr_t buf, ptr;
 	iplog_t *ipl;
 	size_t len;
 	int i;
+	SPL_INT(s);
 
 	/*
 	 * Check to see if this log record has a CRC which matches the last
@@ -419,7 +423,7 @@ int *types, cnt;
 	 */
 	if (ipl_suppress) {
 		MUTEX_ENTER(&ipl_mutex);
-		if (fin != NULL) {
+		if ((fin != NULL) && (fin->fin_off == 0)) {
 			if ((ipll[dev] != NULL) &&
 			    bcmp((char *)fin, (char *)&iplcrc[dev],
 				 FI_LCSIZE) == 0) {
@@ -446,14 +450,17 @@ int *types, cnt;
 	KMALLOCS(buf, caddr_t, len);
 	if (buf == NULL)
 		return -1;
+	SPL_NET(s);
 	MUTEX_ENTER(&ipl_mutex);
-	if ((iplused[dev] + len) > IPFILTER_LOGSIZE) {
+	if ((iplused[dev] + len) > ipl_logsize) {
 		MUTEX_EXIT(&ipl_mutex);
+		SPL_X(s);
 		KFREES(buf, len);
 		return -1;
 	}
 	iplused[dev] += len;
 	MUTEX_EXIT(&ipl_mutex);
+	SPL_X(s);
 
 	/*
 	 * advance the log pointer to the next empty record and deduct the
@@ -475,14 +482,15 @@ int *types, cnt;
 	 * Loop through all the items to be logged, copying each one to the
 	 * buffer.  Use bcopy for normal data or the mb_t copyout routine.
 	 */
-	for (i = 0, s = buf + sizeof(*ipl); i < cnt; i++) {
+	for (i = 0, ptr = buf + sizeof(*ipl); i < cnt; i++) {
 		if (types[i] == 0) {
-			bcopy(items[i], s, itemsz[i]);
+			bcopy(items[i], ptr, itemsz[i]);
 		} else if (types[i] == 1) {
-			COPYDATA(items[i], 0, itemsz[i], s);
+			COPYDATA(items[i], 0, itemsz[i], ptr);
 		}
-		s += itemsz[i];
+		ptr += itemsz[i];
 	}
+	SPL_NET(s);
 	MUTEX_ENTER(&ipl_mutex);
 	ipll[dev] = ipl;
 	*iplh[dev] = ipl;
@@ -499,6 +507,7 @@ int *types, cnt;
 	MUTEX_EXIT(&ipl_mutex);
 	WAKEUP(iplh,dev);
 # endif
+	SPL_X(s);
 # ifdef	IPL_SELECT
 	iplog_input_ready(dev);
 # endif
@@ -525,9 +534,7 @@ struct uio *uio;
 	size_t dlen, copied;
 	int error = 0;
 	iplog_t *ipl;
-# if defined(_KERNEL) && !defined(MENTAT) && defined(USE_SPL)
-	int s;
-# endif
+	SPL_INT(s);
 
 	/*
 	 * Sanity checks.  Make sure the minor # is valid and we're copying
@@ -538,7 +545,7 @@ struct uio *uio;
 	if (uio->uio_resid == 0)
 		return 0;
 	if ((uio->uio_resid < sizeof(iplog_t)) ||
-	    (uio->uio_resid > IPFILTER_LOGSIZE))
+	    (uio->uio_resid > ipl_logsize))
 		return EINVAL;
 
 	/*
@@ -639,7 +646,9 @@ minor_t unit;
 {
 	iplog_t *ipl;
 	int used;
+	SPL_INT(s);
 
+	SPL_NET(s);
 	MUTEX_ENTER(&ipl_mutex);
 	while ((ipl = iplt[unit]) != NULL) {
 		iplt[unit] = ipl->ipl_next;
@@ -651,6 +660,7 @@ minor_t unit;
 	iplused[unit] = 0;
 	bzero((char *)&iplcrc[unit], FI_CSIZE);
 	MUTEX_EXIT(&ipl_mutex);
+	SPL_X(s);
 	return used;
 }
 #endif /* IPFILTER_LOG */
