@@ -3,7 +3,7 @@
  *
  * See the IPFILTER.LICENCE file for details on licencing.
  *
- * $Id: parse.c,v 1.34 2003/12/01 01:58:12 darrenr Exp $
+ * $Id: parse.c,v 1.34.2.1 2004/12/09 19:41:21 darrenr Exp $
  */
 #include <ctype.h>
 #include "ipf.h"
@@ -31,7 +31,7 @@ int     linenum;
 			return NULL;
 	}
 
-	while (*line && isspace(*line))
+	while (*line && ISSPACE(*line))
 		line++;
 	if (!*line)
 		return NULL;
