@@ -3,7 +3,7 @@
  *
  * See the IPFILTER.LICENCE file for details on licencing.
  *
- * $Id: printlog.c,v 1.6 2002/01/28 06:50:47 darrenr Exp $
+ * $Id: printlog.c,v 1.6.4.1 2005/11/14 17:45:06 darrenr Exp $
  */
 
 #include "ipf.h"
@@ -25,12 +25,9 @@ frentry_t *fp;
 		printf(" or-block");
 	if (fp->fr_loglevel != 0xffff) {
 		printf(" level ");
-		if (fp->fr_loglevel & LOG_FACMASK) {
-			s = fac_toname(fp->fr_loglevel);
-			if (s == NULL)
-				s = "!!!";
-		} else
-			s = "";
+		s = fac_toname(fp->fr_loglevel);
+		if (s == NULL)
+			s = "!!!";
 		u = pri_toname(fp->fr_loglevel);
 		if (u == NULL)
 			u = "!!!";
