@@ -25,7 +25,11 @@
 #include <netinet/ip_auth.h>
 #include <netinet/ip_frag.h>
 
+#if __FreeBSD_version >= 502116
+static struct cdev *ipf_devs[IPL_LOGSIZE];
+#else
 static dev_t ipf_devs[IPL_LOGSIZE];
+#endif
 
 static int sysctl_ipf_int ( SYSCTL_HANDLER_ARGS );
 static int ipf_modload(void);
@@ -55,14 +59,14 @@ SYSCTL_IPF(_net_inet_ipf, OID_AUTO, fr_tcpclosed, CTLFLAG_RWO,
 	   &fr_tcpclosed, 0, "");
 SYSCTL_IPF(_net_inet_ipf, OID_AUTO, fr_udptimeout, CTLFLAG_RWO,
 	   &fr_udptimeout, 0, "");
+SYSCTL_IPF(_net_inet_ipf, OID_AUTO, fr_udpacktimeout, CTLFLAG_RWO,
+	   &fr_udpacktimeout, 0, "");
 SYSCTL_IPF(_net_inet_ipf, OID_AUTO, fr_icmptimeout, CTLFLAG_RWO,
 	   &fr_icmptimeout, 0, "");
 SYSCTL_IPF(_net_inet_ipf, OID_AUTO, fr_defnatage, CTLFLAG_RWO,
 	   &fr_defnatage, 0, "");
 SYSCTL_IPF(_net_inet_ipf, OID_AUTO, fr_ipfrttl, CTLFLAG_RW,
 	   &fr_ipfrttl, 0, "");
-SYSCTL_IPF(_net_inet_ipf, OID_AUTO, fr_unreach, CTLFLAG_RW,
-	   &fr_unreach, 0, "");
 SYSCTL_IPF(_net_inet_ipf, OID_AUTO, fr_running, CTLFLAG_RD,
 	   &fr_running, 0, "");
 SYSCTL_IPF(_net_inet_ipf, OID_AUTO, fr_statesize, CTLFLAG_RWO,
@@ -89,19 +93,26 @@ SYSCTL_IPF(_net_inet_ipf, OID_AUTO, fr_minttl, CTLFLAG_RW, &fr_minttl, 0, "");
 #define CDEV_MAJOR 79
 #if __FreeBSD_version >= 501000
 static struct cdevsw ipl_cdevsw = {
+# if __FreeBSD_version >= 502103
+	.d_version =	D_VERSION,
+	.d_flags =	0,	/* D_NEEDGIANT - Should be SMP safe */
+# endif
 	.d_open =	iplopen,
 	.d_close =	iplclose,
 	.d_read =	iplread,
+	.d_write =	iplwrite,
 	.d_ioctl =	iplioctl,
 	.d_name =	"ipl",
+# if __FreeBSD_version < 600000
 	.d_maj =	CDEV_MAJOR,
+# endif
 };
 #else
 static struct cdevsw ipl_cdevsw = {
 	/* open */	iplopen,
 	/* close */	iplclose,
 	/* read */	iplread,
-	/* write */	nowrite,
+	/* write */	iplwrite,
 	/* ioctl */	iplioctl,
 	/* poll */	nopoll,
 	/* mmap */	nommap,
@@ -119,7 +130,8 @@ static struct cdevsw ipl_cdevsw = {
 #endif
 
 static char *ipf_devfiles[] = {	IPL_NAME, IPNAT_NAME, IPSTATE_NAME, IPAUTH_NAME,
-				IPSCAN_NAME, IPSYNC_NAME, IPLOOKUP_NAME, NULL };
+				IPSYNC_NAME, IPSCAN_NAME, IPLOOKUP_NAME, NULL };
+
 
 static int
 ipfilter_modevent(module_t mod, int type, void *unused)
@@ -197,9 +209,15 @@ ipf_modunload()
 {
 	int error, i;
 
-	error = ipldetach();
-	if (error != 0)
-		return error;
+	if (fr_refcnt)
+		return EBUSY;
+
+	if (fr_running >= 0) {
+		error = ipldetach();
+		if (error != 0)
+			return error;
+	} else
+		error = 0;
 
 	fr_running = -2;
 
@@ -215,13 +233,16 @@ ipf_modunload()
 
 
 static moduledata_t ipfiltermod = {
-	IPL_VERSION,
+	"ipfilter",
 	ipfilter_modevent,
 	0
 };
 
 
 DECLARE_MODULE(ipfilter, ipfiltermod, SI_SUB_PROTO_DOMAIN, SI_ORDER_ANY);
+#ifdef	MODULE_VERSION
+MODULE_VERSION(ipfilter, 1);
+#endif
 
 
 #ifdef SYSCTL_IPF
