@@ -76,7 +76,7 @@
 
 #if !defined(lint)
 static const char sccsid[] = "@(#)ipmon.c	1.21 6/5/96 (C)1993-2000 Darren Reed";
-static const char rcsid[] = "@(#)$Id: ipmon.c,v 1.33 2004/01/31 15:03:10 darrenr Exp $";
+static const char rcsid[] = "@(#)$Id: ipmon.c,v 1.33.2.10 2005/06/18 02:41:35 darrenr Exp $";
 #endif
 
 
@@ -134,10 +134,8 @@ static	char	*pidfile = "/etc/ipmon.pid";
 
 static	char	line[2048];
 static	int	opts = 0;
-static	FILE	*newlog = NULL;
 static	char	*logfile = NULL;
 static	FILE	*binarylog = NULL;
-static	FILE	*newbinarylog = NULL;
 static	char	*binarylogfile = NULL;
 static	int	donehup = 0;
 static	void	usage __P((char *));
@@ -389,17 +387,7 @@ size_t tablesz;
 static void handlehup(sig)
 int sig;
 {
-	FILE	*fp;
-
-	if (donehup == 1)
-		return;
-
 	signal(SIGHUP, handlehup);
-	if (logfile && (fp = fopen(logfile, "a")))
-		newlog = fp;
-	if (binarylogfile && (fp = fopen(binarylogfile, "a")))
-		newbinarylog = fp;
-	init_tabs();
 	donehup = 1;
 }
 
@@ -430,6 +418,14 @@ static void init_tabs()
 			    p->p_name != NULL && protocols[p->p_proto] == NULL)
 				protocols[p->p_proto] = strdup(p->p_name);
 		endprotoent();
+#if defined(_AIX51)
+		if (protocols[0])
+			free(protocols[0]);
+		if (protocols[252])
+			free(protocols[252]);
+		protocols[0] = "ip";
+		protocols[252] = NULL;
+#endif
 	}
 
 	if (udp_ports != NULL) {
@@ -666,7 +662,7 @@ int	len;
 			sprintf((char *)t, "        ");
 			t += 8;
 			for (k = 16; k; k--, s++)
-				*t++ = (isprint(*s) ? *s : '.');
+				*t++ = (ISPRINT(*s) ? *s : '.');
 			s--;
 		}
 			
@@ -684,7 +680,7 @@ int	len;
 		t += 7;
 		s -= j & 0xf;
 		for (k = j & 0xf; k; k--, s++)
-			*t++ = (isprint(*s) ? *s : '.');
+			*t++ = (ISPRINT(*s) ? *s : '.');
 		*t++ = '\n';
 		*t = '\0';
 	}
@@ -864,6 +860,13 @@ int	blen;
 		(void) sprintf(t, "%s PR icmpv6 %d",
 			hostname(res, sl->isl_v, (u_32_t *)&sl->isl_dst),
 			sl->isl_itype);
+	} else {
+		(void) sprintf(t, "%s -> ",
+			hostname(res, sl->isl_v, (u_32_t *)&sl->isl_src));
+		t += strlen(t);
+		(void) sprintf(t, "%s PR %s",
+			hostname(res, sl->isl_v, (u_32_t *)&sl->isl_dst),
+			proto);
 	}
 	t += strlen(t);
 	if (sl->isl_tag != FR_NOLOGTAG) {
@@ -873,7 +876,14 @@ int	blen;
 	if (sl->isl_type != ISL_NEW) {
 		sprintf(t,
 #ifdef	USE_QUAD_T
+#ifdef	PRId64
+			" Forward: Pkts in %" PRId64 " Bytes in %" PRId64
+			" Pkts out %" PRId64 " Bytes out %" PRId64
+			" Backward: Pkts in %" PRId64 " Bytes in %" PRId64
+			" Pkts out %" PRId64 " Bytes out %" PRId64,
+#else
 			" Forward: Pkts in %qd Bytes in %qd Pkts out %qd Bytes out %qd Backward: Pkts in %qd Bytes in %qd Pkts out %qd Bytes out %qd",
+#endif /* PRId64 */
 #else
 			" Forward: Pkts in %ld Bytes in %ld Pkts out %ld Bytes out %ld Backward: Pkts in %ld Bytes in %ld Pkts out %ld Bytes out %ld",
 #endif
@@ -928,25 +938,16 @@ int	logtype, blen;
 		}
 
 		if (logtype == IPL_LOGIPF) {
-			if (ipl->ipl_magic != IPL_MAGIC) {
-				/* invalid data or out of sync */
-				break;
-			}
-			print_ipflog(log, buf, psize);
+			if (ipl->ipl_magic == IPL_MAGIC)
+				print_ipflog(log, buf, psize);
 
 		} else if (logtype == IPL_LOGNAT) {
-			if (ipl->ipl_magic != IPL_MAGIC_NAT) {
-				/* invalid data or out of sync */
-				break;
-			}
-			print_natlog(log, buf, psize);
+			if (ipl->ipl_magic == IPL_MAGIC_NAT)
+				print_natlog(log, buf, psize);
 
 		} else if (logtype == IPL_LOGSTATE) {
-			if (ipl->ipl_magic != IPL_MAGIC_STATE) {
-				/* invalid data or out of sync */
-				break;
-			}
-			print_statelog(log, buf, psize);
+			if (ipl->ipl_magic == IPL_MAGIC_STATE)
+				print_statelog(log, buf, psize);
 		}
 
 		blen -= psize;
@@ -1014,7 +1015,7 @@ int	blen;
 	(void) sprintf(t, "%s", ifname);
 	t += strlen(t);
 # if defined(MENTAT) || defined(linux)
-	if (isalpha(*(t - 1))) {
+	if (ISALPHA(*(t - 1))) {
 		sprintf(t, "%d", ipf->fl_unit);
 		t += strlen(t);
 	}
@@ -1029,7 +1030,8 @@ int	blen;
 	(void) sprintf(t, "%*.*s%u", len, len, ipf->fl_ifname, ipf->fl_unit);
 	t += strlen(t);
 #endif
-#ifdef __sgi
+#if defined(__sgi) || defined(_AIX51) || defined(__powerpc__) || \
+    defined(__arm__)
 	if ((ipf->fl_group[0] == 255) && (ipf->fl_group[1] == '\0'))
 #else
 	if ((ipf->fl_group[0] == -1) && (ipf->fl_group[1] == '\0'))
@@ -1087,7 +1089,7 @@ int	blen;
 		p = (u_short)ip6->ip6_nxt;
 		s = (u_32_t *)&ip6->ip6_src;
 		d = (u_32_t *)&ip6->ip6_dst;
-		plen = ntohs(ip6->ip6_plen);
+		plen = hl + ntohs(ip6->ip6_plen);
 #else
 		sprintf(t, "ipv6");
 		goto printipflog;
@@ -1206,11 +1208,13 @@ int	blen;
 					IP_HL(ipc) << 2, i);
 				t += strlen(t);
 				if (ipoff & IP_OFFMASK) {
-					(void) sprintf(t, " frag %s%s%hu@%hu",
-						ipoff & IP_MF ? "+" : "",
-						ipoff & IP_DF ? "-" : "",
+					(void) sprintf(t,
+						"(frag %d:%hu@%hu%s%s)",
+						ntohs(ipc->ip_id),
 						i - (IP_HL(ipc) << 2),
-						(ipoff & IP_OFFMASK) << 3);
+						(ipoff & IP_OFFMASK) << 3,
+						ipoff & IP_MF ? "+" : "",
+						ipoff & IP_DF ? "-" : "");
 				}
 			}
 
@@ -1222,10 +1226,11 @@ int	blen;
 			hostname(res, v, d), proto, hl, plen);
 		t += strlen(t);
 		if (off & IP_OFFMASK)
-			(void) sprintf(t, " frag %s%s%hu@%hu",
+			(void) sprintf(t, " (frag %d:%hu@%hu%s%s)",
+				ntohs(ip->ip_id),
+				plen - hl, (off & IP_OFFMASK) << 3,
 				ipoff & IP_MF ? "+" : "",
-				ipoff & IP_DF ? "-" : "",
-				plen - hl, (off & IP_OFFMASK) << 3);
+				ipoff & IP_DF ? "-" : "");
 	}
 	t += strlen(t);
 
@@ -1412,6 +1417,7 @@ char *argv[];
 {
 	struct	stat	sb;
 	FILE	*log = stdout;
+	FILE	*fp;
 	int	fd[3], doread, n, i;
 	int	tr, nr, regular[3], c;
 	int	fdt[3], devices = 0, make_daemon = 0;
@@ -1615,16 +1621,15 @@ char *argv[];
 
 			tr = read_log(fd[i], &n, buf, sizeof(buf));
 			if (donehup) {
-				if (newlog) {
+				if (logfile && (fp = fopen(logfile, "a"))) {
 					fclose(log);
-					log = newlog;
-					newlog = NULL;
+					log = fp;
 				}
-				if (newbinarylog) {
+				if (binarylogfile && (fp = fopen(binarylogfile, "a"))) {
 					fclose(binarylog);
-					binarylog = newbinarylog;
-					newbinarylog = NULL;
+					binarylog = fp;
 				}
+				init_tabs();
 				if (conf_file != NULL)
 					load_config(conf_file);
 				donehup = 0;
